import {
    Http, IEventParam, Metadata,
} from '@zeedhi/core';
import {
    DialogService, LoadingService, TextInput,
} from '@zeedhi/common';
import { TekGrid } from '@zeedhi/teknisa-components-common';
import { Utilities } from '@/util/Utilities';

export class Sm00016000TipoAnexoController {
    public addNewRow({ component }: IEventParam<TekGrid>) {
        const newId = 0;
        component.addNewRow({ NRTIPOANEXO: newId, IDATIVO: 'S' }, 'start');
        setTimeout(() => {
            const nameInput = Metadata.getInstance<TextInput>(`NMTIPOANEXO_editable_${newId}`);
            nameInput.setFocus();
        }, 100);
    }

    public afterModify() {
        Metadata.getInstance<TekGrid>('anexo-tek-grid').datasource.get();
    }

    public editarTiposAnexos({ component, event }: IEventParam<TekGrid>) {
        event?.preventDefault();
        if (Utilities.validateGrid(component)) {
            LoadingService.show();
            Http.post('/tipoAnexo', {
                DRG: component.getEditedRows(),
            }).then(() => {
                component.datasource.get();
                Utilities.showSuccessMessage();
            }).catch((error: any) => {
                Utilities.showErrorMessage(error);
            }).finally(() => {
                component.cancelEditedRows();
                LoadingService.hide();
            });
        }
    }

    public excluirTiposAnexos({ event }: any) {
        Utilities.showConfirmDeleteMessage(event, 'Sm00016000TipoAnexoController.aposConfirmarDelete');
    }

    public aposConfirmarDelete() {
        const component = Metadata.getInstance<TekGrid>('anexo-tek-grid');
        LoadingService.show();
        Http.post('/excluirTipoAnexo', {
            NRS: component.selectedRows.map((element: any) => element.NRTIPOANEXO),
        }).then(() => {
            component.datasource.get();
            Utilities.showSuccessMessage();
        }).catch((error: any) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            component.selectedRows = [];
            LoadingService.hide();
            DialogService.hide();
        });
    }
}
